Index: src/stub-cache.h |
diff --git a/src/stub-cache.h b/src/stub-cache.h |
index 2d061ab2a98687ba4a07f9e05070ce4bbabb0f8b..360bbfb5ade6ee53b7925cb62696742ef287f4c0 100644 |
--- a/src/stub-cache.h |
+++ b/src/stub-cache.h |
@@ -929,13 +929,9 @@ class CallStubCompiler: public StubCompiler { |
PropertyIndex index, |
Handle<Name> name); |
- // Patch the global proxy over the global object if the global object is the |
- // receiver. |
- static void FetchGlobalProxy(MacroAssembler* masm, |
- Register target, |
- Register function); |
- void PatchGlobalProxy(Handle<Object> object, Register function); |
- void PatchGlobalProxy(Handle<Object> object, Handle<JSFunction> function); |
+ // Patch the implicit receiver over the global object if the global object is |
+ // the receiver. |
+ void PatchImplicitReceiver(Handle<Object> object); |
// Returns the register containing the holder of |name|. |
Register HandlerFrontendHeader(Handle<Object> object, |